#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from pathlib import Path

from snakemake.logging import logger
from snakemake.utils import validate
import re
from .global_variables import *
from snakecdysis import *

class Rnaja(SnakEcdysis):
    """
    to read file config
    """
    def __init__(self, dico_tool, workflow, config):
        super().__init__(**dico_tool, workflow=workflow, config=config)

        # Initialisation of RNAja attributes
        self.fastq_files_list = None
        self.fastq_files_ext = None
        self.fastq_gzip = None
        self.samples_names_list = None
        self.forward = None
        self.reverse = None
        self.paired = None
        self.fastq_path = None

        #populating samples identifiers
        self.fastq_files_list, self.fastq_files_ext, self.fastq_gzip = get_files_ext2(
        self.get_config_value('DATA', 'fastq_dir'), ALLOW_FASTQ_EXT)
        self.fastq_path = self.get_config_value('DATA', 'fastq_dir')
        # check output mandatory directory
        self.check_dir_or_string(level1="DATA", level2="output_dir")
        self.reference = self.get_config_value('DATA', 'reference')
        self.annotation = self.get_config_value('DATA', 'annotation')
        #self.sample_info = self.get_config_value(level1="DATA", level2="sample_info")
        #self.de_comparisons = self.get_config_value(level1="DATA", level2="de_comparisons")

        self.check_dir_or_string(level1="DATA", level2="fastq_dir")


        self.samples_names_list = set([Path(elm).stem.split("_")[0] if "_" in elm else Path(
            elm).stem if not self.fastq_gzip else Path(elm).stem.split(".")[0] for elm in
                                 self.fastq_files_list])

        self.forward, self.reverse = self.__split_illumina()
        if len(self.reverse) == 0:
            self.paired = False
        else :
            self.paired = True

        if self.paired and (len(self.reverse) != len(self.forward)):
            raise ValueError(
                f"DATA CHECKING FAIL : The samples are paired but there there is missing R1 or R2\n")

        if len(self.forward) == 0:
            raise ValueError(
                f"DATA CHECKING FAIL : you need to rename your fastq file using this model : condition-rep1_R1.fastq.gz \n")

    def __split_illumina(self):
        forward = []
        reverse = []
        for fastq in self.fastq_files_list:
            if '_R1' in fastq:
                forward.append(fastq)
            elif '_R2' in fastq:
                reverse.append(fastq)
        return forward, reverse


